# Generated by roxygen2: do not edit by hand

S3method(diagnostics,multiScaleR)
S3method(plot,multiScaleR)
S3method(plot,sigma_profile)
S3method(print,multiScaleR)
S3method(print,multiScaleR_data)
S3method(print,multiScaleR_ram)
S3method(print,multiScaleR_vars)
S3method(print,summary_multiScaleR)
S3method(summary,multiScaleR)
export(aic_tab)
export(bic_tab)
export(diagnostics)
export(estimate_multiscale_ram)
export(kernel_dist)
export(kernel_prep)
export(kernel_scale.raster)
export(kernel_var)
export(landscape_var)
export(msr_vars)
export(multiScale_optim)
export(plot_kernel)
export(plot_marginal_effects)
export(profile_sigma)
export(sim_dat)
export(sim_dat_unmarked)
export(sim_rast)
export(surface_var)
importFrom(AICcmodavg,aictabCustom)
importFrom(AICcmodavg,bictabCustom)
importFrom(Matrix,as.matrix)
importFrom(Rcpp,evalCpp)
importFrom(cowplot,theme_cowplot)
importFrom(crayon,"%+%")
importFrom(crayon,blue)
importFrom(crayon,bold)
importFrom(crayon,green)
importFrom(crayon,red)
importFrom(dplyr,bind_rows)
importFrom(exactextractr,exact_extract)
importFrom(fields,rdist)
importFrom(fields,rdist.earth)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_light)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(insight,find_formula)
importFrom(insight,find_predictors)
importFrom(insight,get_call)
importFrom(insight,get_data)
importFrom(insight,get_df)
importFrom(insight,get_loglikelihood)
importFrom(insight,get_parameters)
importFrom(insight,get_predicted)
importFrom(insight,link_inverse)
importFrom(insight,n_obs)
importFrom(methods,as)
importFrom(methods,getClassDef)
importFrom(methods,is)
importFrom(optimParallel,optimParallel)
importFrom(parallel,clusterEvalQ)
importFrom(parallel,clusterExport)
importFrom(parallel,makeCluster)
importFrom(parallel,makeForkCluster)
importFrom(parallel,parLapply)
importFrom(parallel,setDefaultCluster)
importFrom(parallel,stopCluster)
importFrom(pscl,zeroinfl)
importFrom(sf,"st_crs<-")
importFrom(sf,st_as_sf)
importFrom(sf,st_buffer)
importFrom(sf,st_coordinates)
importFrom(sf,st_crs)
importFrom(sf,st_make_grid)
importFrom(stats,dist)
importFrom(stats,fft)
importFrom(stats,formula)
importFrom(stats,integrate)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,optim)
importFrom(stats,plogis)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnbinom)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,uniroot)
importFrom(terra,"crs<-")
importFrom(terra,"ext<-")
importFrom(terra,"values<-")
importFrom(terra,as.int)
importFrom(terra,as.matrix)
importFrom(terra,as.polygons)
importFrom(terra,cellFromRowCol)
importFrom(terra,clamp)
importFrom(terra,crds)
importFrom(terra,crs)
importFrom(terra,ext)
importFrom(terra,focal)
importFrom(terra,minmax)
importFrom(terra,ncol)
importFrom(terra,nlyr)
importFrom(terra,nrow)
importFrom(terra,plot)
importFrom(terra,rast)
importFrom(terra,res)
importFrom(terra,subset)
importFrom(terra,values)
importFrom(terra,vect)
importFrom(terra,xyFromCell)
importFrom(unmarked,coef)
importFrom(unmarked,predict)
importFrom(utils,getS3method)
importFrom(utils,globalVariables)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(multiScaleR, .registration=TRUE)
